# Changes

## 0.6.6
* Added 2025 PAP

## 0.6.5
* Added 2024 december PAP

## 0.6.4
* Added 2024 PAP (thanks antonio-masotti)

## 0.6.3
* Added fix for rounding in BigDecimal.SetScale for golang. (thanks Markus)

## 0.6.2
* Added 2023 PAP from July

## 0.6.1
* Added 2023 PAP

## 0.6.0
* Added golang generator which supersedes go generator (thanks polderudo)
* Fixed empty if-body in python
* Added javascript example (thanks 0xCCD)
* Added 2022 PAP (thanks 0xCCD)

## 0.5.4
* Added php BigDecimal fixes (thanks tburschka)

## 0.5.3
* Added python3.9 ast module compatiblity

## 0.5.2
* Added resources for year 2021 (thanks 0xCCD)

## 0.5.1
* Added fix for double types in Go (thanks knipknap)

## 0.5.0
* Added Go support (thanks knipknap for the code and Dexus for the review!)

## 0.4.3
* Fixed default value for "double" numbers
* Removee size literals (L/D) in python code
* Improved PAP naming (thanks knipknap)

## 0.4.2
* Added resources for year 2020 (thanks csarn)
* Fixed README python example (thanks csarn)

## 0.4.1
* Fixed CLI examples in README

## 0.4.0
* Added PAP for 2018 and 2019
* Fixed BMF URIs
* Added "version" cli option 

## 0.3.2
* Make pypi happy

## 0.3.1
* Added support for 2017 PAP
* Fixed unary operator conversion
* Replaced Decimal.\_rescale with Decimal.quantize to
  remain python3 compliant

## 0.3.0
* Added JS support
* Refactored generators for java-like languages
* Cleaned up a bit to satisfy pylint

## 0.2.0
* Refactored writers to generators
* Added basic tests
* Added BigDecimal PHP proxy class

## 0.1.1
* Fixed packaging issues for README.md and CHANGES.md

## 0.1.0
* Initial version
